@@ -6,12 +6,11 @@
                     ...) { 
   
   FitMultinomial         <- function(true,dat){
-    temp <- dat*log10(true); 
-    if (sum(is.na(temp)) > 0) {
-      #temp[is.na(temp)] <- 0;
-      return(-Inf);
-    } else { return(sum(temp));}
+    true[true == 0] <- 1
+    return(sum(dat*log(true)))
   }
+  oopts <- options(scipen = 999)
+  on.exit(options(oopts))
   count <- 0
   
   ### Two passes to find optimal r #######
