@@ -1,7 +1,7 @@
 print.CV_Result <- function(x,...){
     cat("\nContaining the cross validation result. \n");
     if (!is.null(x$s_optimal))
-        cat(paste0("Optimal r parameter is: ", x$r_optimal, "\n"));
+        cat(paste0("Selected r parameter is:", x$r_optimal, "\n"));
     if (!is.null(x$s_optimal))
-        cat(paste0("Optimal s parameter is: ", x$s_optimal, "\n"));
+        cat(paste0("Selected s parameter is:", x$s_optimal, "\n"));
 }
\ No newline at end of file
