@@ -13,12 +13,12 @@ print.PAFit_result <- function(x,...) {
   #cat(" Form of the PA function:",x$mode_f,"\n");
   if (x$only_f == FALSE) {
       if (x$auto_lambda == TRUE) {
-          cat("Ratio (r):", x$ratio,"\n");
+          cat("Selected r parameter:", x$ratio,"\n");  
       } else cat("Lambda used:", x$lambda,"\n");
   }
   
   if (x$only_PA == FALSE)
-      cat("Prior of node fitness: shape: ",x$shape,"; rate: ",x$rate,"\n", sep = "")
+      cat("Selected s parameter: ",x$shape,"\n", sep = "")
   cat("Estimated attachment exponent:",x$alpha,"\n");
   if (x$ci[1] == "N") {
     cat("No possible confidence interval for the estimated attachment exponent.\n");
