@@ -1,7 +1,7 @@
 library(PAFit)
 
 net  <- generate_net(N = 50, m = 10, mode = 1, s = 100, 
-                     no_new_node_step = NULL)
+                     no_new_node_step = 0)
 
 
 
